Project::OSiRiON - Git repositories
Project::OSiRiON
News . About . Screenshots . Downloads . Forum . Wiki . Tracker . Git
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorStijn Buys <ingar@osirion.org>2007-10-21 15:18:50 +0000
committerStijn Buys <ingar@osirion.org>2007-10-21 15:18:50 +0000
commit97cbb7514135ec81803e746f0b549e9f95abbecc (patch)
tree6d61b17ed1485a5488522dd41011a4225cde18b0 /src/game/sector.h
parent783545505aa51e4f908932fffb1f8362ad898d44 (diff)
added basic file loader
Diffstat (limited to 'src/game/sector.h')
-rw-r--r--src/game/sector.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/src/game/sector.h b/src/game/sector.h
index 10f548c..3f6b3e4 100644
--- a/src/game/sector.h
+++ b/src/game/sector.h
@@ -10,13 +10,17 @@
namespace game
{
+
+/// a sector of space
class Sector {
public:
+ /// default constructor
Sector();
+ /// default destructor
~Sector();
- /// tag used in configuration files, e.g. "terran"
- std::string tag;
+ /// label used in configuration files, e.g. "terran"
+ std::string label;
/// name to display, e.g. "Terran System"
std::string name;
};